==> nextcloud-18.0.3.tgz: nextcloud/apps/accessibility/l10n/el.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Σκούρο θέμα",
    "Enable dark theme" : "Ενεργοποίηση σκούρου θέματος",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ένα σκοτεινό θέμα που διευκολύνει τα μάτια σας μειώνοντας την συνολική ακτινοβολία και φωτεινότητα. Είναι ακόμη υπό δοκιμή, οπότε θα σας παρακαλούσαμε να αναφέρετε οποιαδήποτε προβλήματα παρατηρηθούν.",
    "High contrast mode" : "Λειτουργία υψηλής αντίθεσης",
    "Enable high contrast mode" : "Ενεργοποίηση λειτουργίας υψηλής αντίθεσης",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Λειτουργία με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "Enable dyslexia font" : "Ενεργοποίηση γραμματοσειράς για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη προβλήματα που προκαλεί η δυσλεξία στην ανάγνωση",
    "Accessibility" : "Προσβασιμότητα",
    "Accessibility options for nextcloud" : "Ρυθμίσεις προσβασιμότητας του nextcloud.",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Προσφέρει πολλαπλές επιλογές προσβασιμότητας για να διευκολύνουν τη χρήση του Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η γενική πρόσβαση είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με την {guidelines} Πρόσβαση Περιεχομένου Ιστού Guidelines{linkend} 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Αν διαπιστώσετε τυχόν προβλήματα, μη διστάσετε να τα αναφέρετε στον {issuetracker} στον διακομιστή προβλημάτων μας{linkend}. Και αν θέλετε να εμπλακείτε, ελάτε στο {designteam} στην ομάδα σχεδιασμού μας{linkend}!",
    "High contrast theme" : "Θέμα υψηλής αντίθεσης",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ένα θέμα με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dark theme (beta)" : "Σκοτεινό θέμα (δοκιμαστική έκδοση)",
    "Web Content Accessibility Guidelines" : "Οδηγίες προσβασιμότητας περιεχομένου ιστού",
    "our issue tracker" : "ο ανιχνευτής ζητημάτων μας",
    "our design team" : "η σχεδιαστική ομάδα μας",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η γενική πρόσβαση είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με την {guidelines} 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Αν διαπιστώσετε τυχόν προβλήματα, μη διστάσετε να τα αναφέρετε στον {issuetracker}. Και αν θέλετε να εμπλακείτε, έρθετε στο {designteam}!",
    "Enable" : "Ενεργοποίηση"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/accessibility/l10n/el.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "Σκούρο θέμα",
    "Enable dark theme" : "Ενεργοποίηση σκούρου θέματος",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Ένα σκούρο θέμα που διευκολύνει τα μάτια σας μειώνοντας την συνολική ακτινοβολία και φωτεινότητα. Είναι ακόμη υπό δοκιμή, οπότε θα σας παρακαλούσαμε να αναφέρετε οποιαδήποτε προβλήματα παρατηρηθούν.",
    "High contrast mode" : "Λειτουργία υψηλής αντίθεσης",
    "Enable high contrast mode" : "Ενεργοποίηση λειτουργίας υψηλής αντίθεσης",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Λειτουργία με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dyslexia font" : "Γραμματοσειρά για δυσλεκτικούς",
    "Enable dyslexia font" : "Ενεργοποίηση γραμματοσειράς για δυσλεκτικούς",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "Η OpenDyslexic είναι μία δωρεάν γραμματοσειρά σχεδιασμένη ώστε να περιορίζει ορισμένα από τα πιο συνήθη προβλήματα που προκαλεί η δυσλεξία στην ανάγνωση",
    "Accessibility" : "Προσβασιμότητα",
    "Accessibility options for nextcloud" : "Ρυθμίσεις προσβασιμότητας του nextcloud.",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Προσφέρει πολλαπλές επιλογές προσβασιμότητας για να διευκολύνουν τη χρήση του Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η γενική πρόσβαση είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με την {guidelines} Πρόσβαση Περιεχομένου Ιστού Guidelines{linkend} 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Αν διαπιστώσετε τυχόν προβλήματα, μη διστάσετε να τα αναφέρετε στον {issuetracker} στον διακομιστή προβλημάτων μας{linkend}. Και αν θέλετε να εμπλακείτε, ελάτε στο {designteam} στην ομάδα σχεδιασμού μας{linkend}!",
    "High contrast theme" : "Θέμα υψηλής αντίθεσης",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Ένα θέμα με υψηλή αντίθεση για να διευκολύνει την πλοήγηση σας. Η οπτική ποιότητα θα είναι μειωμένη αλλά θα έχετε υψηλότερη ευκρίνεια.",
    "Dark theme (beta)" : "Σκούρο θέμα (δοκιμαστική έκδοση)",
    "Web Content Accessibility Guidelines" : "Οδηγίες προσβασιμότητας περιεχομένου ιστού",
    "our issue tracker" : "ο ανιχνευτής ζητημάτων μας",
    "our design team" : "η σχεδιαστική ομάδα μας",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines} 2.1 on AA level, with the high contrast theme even on AAA level." : "Η γενική πρόσβαση είναι πολύ σημαντική για εμάς. Ακολουθούμε τα πρότυπα του διαδικτύου και ελέγχουμε ότι τα πάντα μπορούν να χρησιμοποιηθούν χωρίς ποντίκι και βοηθητικό λογισμικό όπως προγράμματα ανάγνωσης οθόνης. Στόχος μας είναι να συμμορφωνόμαστε με την {guidelines} 2.1 σε επίπεδο AA, με το θέμα υψηλής αντίθεσης ακόμη και σε επίπεδο ΑΑΑ.",
    "If you find any issues, don’t hesitate to report them on {issuetracker}. And if you want to get involved, come join {designteam}!" : "Αν διαπιστώσετε τυχόν προβλήματα, μη διστάσετε να τα αναφέρετε στον {issuetracker}. Και αν θέλετε να εμπλακείτε, ελάτε στο {designteam}!",
    "Enable" : "Ενεργοποίηση"
},
"nplurals=2; plural=(n != 1);");
